==> artemis_cupps-0.0.3.tar.gz: lib/classes/Devices/bt_device.dart <==
import 'dart:developer';

import '../../classes/Requests/aea_request_req.dart';
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class BtDevice extends Device {
  BtDevice(
      {required BtDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory BtDevice.fromDevice(Device d) {
    return BtDevice(
      deviceParameter: BtDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }

  Future<CuppsCommandResponse> setLogo(String logoText) async {
    AeaRequestRequest req = AeaRequestRequest(
        messageID: currentMessageID, texts: [logoText], binaries: []);
    final setLogoRes = await aeaRequest(req.toXML());
    log("$setLogoRes");
    return setLogoRes;
    // print(setLogoRes);
    // send(xml: req.toXML());
  }

  Future<CuppsCommandResponse> setPectab(String pectabText) async {
    AeaRequestRequest req = AeaRequestRequest(
        messageID: currentMessageID, texts: [pectabText], binaries: []);
    final setPectabRes = await aeaRequest(req.toXML());
    log("$setPectabRes");
    return setPectabRes;
    // print(setPectabRes);
    // send(xml: req.toXML());
  }

  Future<CuppsCommandResponse> printAEA(String text) async {
    AeaRequestRequest req = AeaRequestRequest(
        messageID: currentMessageID, texts: [text], binaries: []);
    final printAeaRes = await aeaRequest(req.toXML());
    log("$printAeaRes");
    return printAeaRes;
    // print(printAeaRes);
    // send(xml: req.toXML());
  }
}

class BtDeviceParameter extends DeviceParameter {
  final String supportsColor;
  final List<SupportedStock> supportedStocks;

  BtDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.supportsColor,
    required this.supportedStocks,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory BtDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("btStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    BtStatus status = BtStatus.fromXML(statusElement!.toXmlString());

    String supportsColor = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "supportsColor")
        .value;

    XmlElement? supportedStocksElement =
        document.firstChild!.getElement("supportedStocks");
    List<XmlElement> supporters = supportedStocksElement == null
        ? []
        : supportedStocksElement.findElements("supportedStock").toList();
    List<SupportedStock> supportedStocks =
        supporters.map((e) => SupportedStock.fromXML(e.toXmlString())).toList();

    return BtDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        supportsColor: supportsColor,
        supportedStocks: supportedStocks);
  }

  @override
  String toXML() {
    return '''
                  <btDeviceParameter supportsColor="$supportsColor" >
                      ${vendorModelInfo.toXML()}
                      ${ipAndPort.toXML()}
                      ${status.toXML()}
                      ${supportedStocks.map((e) => e.toXML()).join()}
                  </btDeviceParameter>
    '''
        .trimer;
  }
}

class BtStatus extends Status {
  final String paperOut;
  final String paperJam;

  BtStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
    required this.paperJam,
    required this.paperOut,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory BtStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    String paperJam = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "paperJam")
        .value;
    String paperOut = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "paperOut")
        .value;
    return BtStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown,
        paperJam: paperJam,
        paperOut: paperOut);
  }

  @override
  String toXML() {
    return '''<btStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown" paperJam="$paperJam" paperOut="$paperOut" />'''
        .trimer;
  }

  bool get isJammed => paperJam == "true";
  bool get isOpen => paperOut == "true";

  @override
  String get image {
    if (isOff) return AssetImages.btIconsAddressDisconnect;
    if (isJammed) return AssetImages.btIconsAddressJammed;
    if (isOpen) return AssetImages.btIconsAddressOpen;
    if (isInit) return AssetImages.btIconsAddressIn;
    if (isReady) return AssetImages.btIconsAddressActive;
    return AssetImages.btIconsAddressNatural;
  }
}

==> artemis_cupps-0.0.28.tar.gz: lib/classes/Devices/bt_device.dart <==
import 'dart:developer';

import '../../classes/Requests/aea_request_req.dart';
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class BtDevice extends Device {
  BtDevice(
      {required BtDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory BtDevice.fromDevice(Device d) {
    return BtDevice(
      deviceParameter: BtDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }

  Future<CuppsCommandResponse> auth({required String airlineID, String mode  = "HDC",String font = "L",}) async {

    // AeaRequestRequest req = AeaRequestRequest(messageID: currentMessageID, texts: ["EP#AIRLINEID=$airlineID#HARDCODE=HDC#FONT=L"],binaries: []);
    final setLogoRes = await aeaRequest("EP#AIRLINEID=$airlineID#HARDCODE=HDC#FONT=$font#ERR3IGN=Y");
    // final setLogoRes = await aeaRequest("EP#AIRLINEID=$airlineID#HARDCODE=$mode#FONT=$font");
    return setLogoRes;
    // print(setLogoRes);
    // send(xml: req.toXML());
  }

  Future<CuppsCommandResponse> setLogo(String logoText) async {
    // AeaRequestRequest req = AeaRequestRequest(messageID: currentMessageID, texts: [logoText], binaries: []);
    final setLogoRes = await aeaRequest(logoText);
    log("$setLogoRes");
    return setLogoRes;
    // print(setLogoRes);
    // send(xml: req.toXML());
  }

  Future<CuppsCommandResponse> setPectab(String pectabText) async {
    // AeaRequestRequest req = AeaRequestRequest(messageID: currentMessageID, texts: [pectabText], binaries: []);
    final setPectabRes = await aeaRequest(pectabText);
    log("$setPectabRes");
    return setPectabRes;
    // print(setPectabRes);
    // send(xml: req.toXML());
  }

  Future<CuppsCommandResponse> printAEA(String text) async {
    // AeaRequestRequest req = AeaRequestRequest(messageID: currentMessageID, texts: [text], binaries: []);
    final printAeaRes = await aeaRequest(text);
    log("$printAeaRes");
    return printAeaRes;
    // print(printAeaRes);
    // send(xml: req.toXML());
  }
}

class BtDeviceParameter extends DeviceParameter {
  final String supportsColor;
  final List<SupportedStock> supportedStocks;

  BtDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.supportsColor,
    required this.supportedStocks,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory BtDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("btStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    BtStatus status = BtStatus.fromXML(statusElement!.toXmlString());

    String supportsColor = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "supportsColor")
        .value;

    XmlElement? supportedStocksElement =
        document.firstChild!.getElement("supportedStocks");
    List<XmlElement> supporters = supportedStocksElement == null
        ? []
        : supportedStocksElement.findElements("supportedStock").toList();
    List<SupportedStock> supportedStocks =
        supporters.map((e) => SupportedStock.fromXML(e.toXmlString())).toList();

    return BtDeviceParameter(
        vendorModelInfo: vendorModelInfo,
        ipAndPort: ipAndPort,
        status: status,
        supportsColor: supportsColor,
        supportedStocks: supportedStocks);
  }

  @override
  String toXML() {
    return '''<btDeviceParameter supportsColor="$supportsColor" >
    ${ipAndPort.toXML()}
    ${status.toXML()}
    ${supportedStocks.map((e) => e.toXML()).join()}
    </btDeviceParameter>
    ''';
  }
}

class BtStatus extends Status {
  final String paperOut;
  final String paperJam;

  BtStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
    required this.paperJam,
    required this.paperOut,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory BtStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    String paperJam = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "paperJam")
        .value;
    String paperOut = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "paperOut")
        .value;
    return BtStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown,
        paperJam: paperJam,
        paperOut: paperOut);
  }

  @override
  String toXML() {
    return '''<btStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown" paperJam="$paperJam" paperOut="$paperOut"/>''';
  }

  bool get isJammed => paperJam == "true";
  bool get isOpen => paperOut == "true";

  @override
  String get image {
    if (isOff) return AssetImages.btIconsAddressDisconnect;
    if (isJammed) return AssetImages.btIconsAddressJammed;
    if (isOpen) return AssetImages.btIconsAddressOpen;
    if (isInit) return AssetImages.btIconsAddressIn;
    if (isReady) return AssetImages.btIconsAddressActive;
    return AssetImages.btIconsAddressNatural;
  }
}
